==> haskell-clock-0.7.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clock.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clock
version: 0.7.2
id: clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
key: clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
license: BSD3
copyright: Copyright © Cetin Sert 2009-2016, Eugene Kirpichov 2010, Finn Espen Gundersen 2013, Gerolf Seitz 2013, Mathieu Boespflug 2014 2015, Chris Done 2015, Dimitri Sabadie 2015, Christian Burger 2015, Mario Longobardi 2016
maintainer: Cetin Sert <cetin@corsis.eu>, Corsis Research
stability: stable
homepage: https://github.com/corsis/clock
synopsis: High-resolution clock functions: monotonic, realtime, cputime.
description:
    A package for convenient access to high-resolution clock and
    timer functions of different operating systems via a unified API.
    .
    POSIX code and surface API was developed by Cetin Sert in 2009.
    .
    Windows code was contributed by Eugene Kirpichov in 2010.
    .
    FreeBSD code was contributed by Finn Espen Gundersen on 2013-10-14.
    .
    OS X code was contributed by Gerolf Seitz on 2013-10-15.
    .
    Derived @Generic@, @Typeable@ and other instances for @Clock@ and @TimeSpec@ was contributed by Mathieu Boespflug on 2014-09-17.
    .
    Corrected dependency listing for @GHC < 7.6@ was contributed by Brian McKenna on 2014-09-30.
    .
    Windows code corrected by Dimitri Sabadie on 2015-02-09.
    .
    Added @timeSpecAsNanoSecs@ as observed widely-used by Chris Done on 2015-01-06, exported correctly on 2015-04-20.
    .
    Imported Control.Applicative operators correctly for Haskell Platform on Windows on 2015-04-21.
    .
    Unit tests and instance fixes by Christian Burger on 2015-06-25.
    .
    Removal of fromInteger : Integer -> TimeSpec by Cetin Sert on 2015-12-15.
    .
    New Linux-specific Clocks: MonotonicRaw, Boottime, MonotonicCoarse, RealtimeCoarse by Cetin Sert on 2015-12-15.
    .
    Reintroduction fromInteger : Integer -> TimeSpec by Cetin Sert on 2016-04-05.
    .
    Fixes for older Linux build failures introduced by new Linux-specific clocks by Mario Longobardi on 2016-04-18.
    .
    [Version Scheme]
    Major-@/R/@-ewrite . New-@/F/@-unctionality . @/I/@-mprovementAndBugFixes . @/P/@-ackagingOnly
    .
    * @PackagingOnly@ changes are made for quality assurance reasons.
category: System
author: Cetin Sert <cetin@corsis.eu>, Corsis Research
exposed: True
indefinite: False
exposed-modules:
    System.Clock
abi: 92f7216679a05fc7241dae2b2b6f6e0e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/clock-0.7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/clock-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/clock-0.7.2
hs-libraries: HSclock-0.7.2-9fV7rV7wNUo6v6mDurfiVg
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-clock/html/clock.haddock
haddock-html: /usr/share/doc/haskell-clock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clock-0.7.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-clock.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clock
version: 0.7.2
id: clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
key: clock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
license: BSD3
copyright: Copyright © Cetin Sert 2009-2016, Eugene Kirpichov 2010, Finn Espen Gundersen 2013, Gerolf Seitz 2013, Mathieu Boespflug 2014 2015, Chris Done 2015, Dimitri Sabadie 2015, Christian Burger 2015, Mario Longobardi 2016
maintainer: Cetin Sert <cetin@corsis.eu>, Corsis Research
stability: stable
homepage: https://github.com/corsis/clock
synopsis: High-resolution clock functions: monotonic, realtime, cputime.
description:
    A package for convenient access to high-resolution clock and
    timer functions of different operating systems via a unified API.
    .
    POSIX code and surface API was developed by Cetin Sert in 2009.
    .
    Windows code was contributed by Eugene Kirpichov in 2010.
    .
    FreeBSD code was contributed by Finn Espen Gundersen on 2013-10-14.
    .
    OS X code was contributed by Gerolf Seitz on 2013-10-15.
    .
    Derived @Generic@, @Typeable@ and other instances for @Clock@ and @TimeSpec@ was contributed by Mathieu Boespflug on 2014-09-17.
    .
    Corrected dependency listing for @GHC < 7.6@ was contributed by Brian McKenna on 2014-09-30.
    .
    Windows code corrected by Dimitri Sabadie on 2015-02-09.
    .
    Added @timeSpecAsNanoSecs@ as observed widely-used by Chris Done on 2015-01-06, exported correctly on 2015-04-20.
    .
    Imported Control.Applicative operators correctly for Haskell Platform on Windows on 2015-04-21.
    .
    Unit tests and instance fixes by Christian Burger on 2015-06-25.
    .
    Removal of fromInteger : Integer -> TimeSpec by Cetin Sert on 2015-12-15.
    .
    New Linux-specific Clocks: MonotonicRaw, Boottime, MonotonicCoarse, RealtimeCoarse by Cetin Sert on 2015-12-15.
    .
    Reintroduction fromInteger : Integer -> TimeSpec by Cetin Sert on 2016-04-05.
    .
    Fixes for older Linux build failures introduced by new Linux-specific clocks by Mario Longobardi on 2016-04-18.
    .
    [Version Scheme]
    Major-@/R/@-ewrite . New-@/F/@-unctionality . @/I/@-mprovementAndBugFixes . @/P/@-ackagingOnly
    .
    * @PackagingOnly@ changes are made for quality assurance reasons.
category: System
author: Cetin Sert <cetin@corsis.eu>, Corsis Research
exposed: True
indefinite: False
exposed-modules:
    System.Clock
abi: 01c820dbfea727c150599d4a04cd30b6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/clock-0.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/clock-0.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/clock-0.7.2
hs-libraries: HSclock-0.7.2-HOYfHHJ3W4Qjx04GjA0Jy
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-clock/html/clock.haddock
haddock-html: /usr/share/doc/haskell-clock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
